@@ -36,4 +36,10 @@ config = dict(
     # hub to not be strict when comparing messages topics to subscription
     # topics.
     zmq_strict=False,
+
+    # TODO - consider removing the whole concept of post_init_sleep in the
+    # future.
+    # This used to be set to 1 for safety, but it turns out it was
+    # unnecessary.
+    post_init_sleep=0,
 )
